import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AssociateManagedNotificationAccountContactRequest, AssociateManagedNotificationAccountContactResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link AssociateManagedNotificationAccountContactCommand}.
 */
export interface AssociateManagedNotificationAccountContactCommandInput extends AssociateManagedNotificationAccountContactRequest {
}
/**
 * @public
 *
 * The output of {@link AssociateManagedNotificationAccountContactCommand}.
 */
export interface AssociateManagedNotificationAccountContactCommandOutput extends AssociateManagedNotificationAccountContactResponse, __MetadataBearer {
}
declare const AssociateManagedNotificationAccountContactCommand_base: {
    new (input: AssociateManagedNotificationAccountContactCommandInput): import("@smithy/smithy-client").CommandImpl<AssociateManagedNotificationAccountContactCommandInput, AssociateManagedNotificationAccountContactCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: AssociateManagedNotificationAccountContactCommandInput): import("@smithy/smithy-client").CommandImpl<AssociateManagedNotificationAccountContactCommandInput, AssociateManagedNotificationAccountContactCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Associates an Account Contact with a particular <code>ManagedNotificationConfiguration</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, AssociateManagedNotificationAccountContactCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, AssociateManagedNotificationAccountContactCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // AssociateManagedNotificationAccountContactRequest
 *   contactIdentifier: "STRING_VALUE", // required
 *   managedNotificationConfigurationArn: "STRING_VALUE", // required
 * };
 * const command = new AssociateManagedNotificationAccountContactCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param AssociateManagedNotificationAccountContactCommandInput - {@link AssociateManagedNotificationAccountContactCommandInput}
 * @returns {@link AssociateManagedNotificationAccountContactCommandOutput}
 * @see {@link AssociateManagedNotificationAccountContactCommandInput} for command's `input` shape.
 * @see {@link AssociateManagedNotificationAccountContactCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>Request would cause a service quota to be exceeded.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class AssociateManagedNotificationAccountContactCommand extends AssociateManagedNotificationAccountContactCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: AssociateManagedNotificationAccountContactRequest;
            output: {};
        };
        sdk: {
            input: AssociateManagedNotificationAccountContactCommandInput;
            output: AssociateManagedNotificationAccountContactCommandOutput;
        };
    };
}
