import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DisableNotificationsAccessForOrganizationRequest, DisableNotificationsAccessForOrganizationResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DisableNotificationsAccessForOrganizationCommand}.
 */
export interface DisableNotificationsAccessForOrganizationCommandInput extends DisableNotificationsAccessForOrganizationRequest {
}
/**
 * @public
 *
 * The output of {@link DisableNotificationsAccessForOrganizationCommand}.
 */
export interface DisableNotificationsAccessForOrganizationCommandOutput extends DisableNotificationsAccessForOrganizationResponse, __MetadataBearer {
}
declare const DisableNotificationsAccessForOrganizationCommand_base: {
    new (input: DisableNotificationsAccessForOrganizationCommandInput): import("@smithy/smithy-client").CommandImpl<DisableNotificationsAccessForOrganizationCommandInput, DisableNotificationsAccessForOrganizationCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DisableNotificationsAccessForOrganizationCommandInput]): import("@smithy/smithy-client").CommandImpl<DisableNotificationsAccessForOrganizationCommandInput, DisableNotificationsAccessForOrganizationCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Disables service trust between User Notifications and Amazon Web Services Organizations.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, DisableNotificationsAccessForOrganizationCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, DisableNotificationsAccessForOrganizationCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = {};
 * const command = new DisableNotificationsAccessForOrganizationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DisableNotificationsAccessForOrganizationCommandInput - {@link DisableNotificationsAccessForOrganizationCommandInput}
 * @returns {@link DisableNotificationsAccessForOrganizationCommandOutput}
 * @see {@link DisableNotificationsAccessForOrganizationCommandInput} for command's `input` shape.
 * @see {@link DisableNotificationsAccessForOrganizationCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>Request would cause a service quota to be exceeded.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class DisableNotificationsAccessForOrganizationCommand extends DisableNotificationsAccessForOrganizationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: {};
            output: {};
        };
        sdk: {
            input: DisableNotificationsAccessForOrganizationCommandInput;
            output: DisableNotificationsAccessForOrganizationCommandOutput;
        };
    };
}
