import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DisassociateManagedNotificationAccountContactRequest, DisassociateManagedNotificationAccountContactResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DisassociateManagedNotificationAccountContactCommand}.
 */
export interface DisassociateManagedNotificationAccountContactCommandInput extends DisassociateManagedNotificationAccountContactRequest {
}
/**
 * @public
 *
 * The output of {@link DisassociateManagedNotificationAccountContactCommand}.
 */
export interface DisassociateManagedNotificationAccountContactCommandOutput extends DisassociateManagedNotificationAccountContactResponse, __MetadataBearer {
}
declare const DisassociateManagedNotificationAccountContactCommand_base: {
    new (input: DisassociateManagedNotificationAccountContactCommandInput): import("@smithy/smithy-client").CommandImpl<DisassociateManagedNotificationAccountContactCommandInput, DisassociateManagedNotificationAccountContactCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DisassociateManagedNotificationAccountContactCommandInput): import("@smithy/smithy-client").CommandImpl<DisassociateManagedNotificationAccountContactCommandInput, DisassociateManagedNotificationAccountContactCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Disassociates an Account Contact with a particular <code>ManagedNotificationConfiguration</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, DisassociateManagedNotificationAccountContactCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, DisassociateManagedNotificationAccountContactCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // DisassociateManagedNotificationAccountContactRequest
 *   contactIdentifier: "STRING_VALUE", // required
 *   managedNotificationConfigurationArn: "STRING_VALUE", // required
 * };
 * const command = new DisassociateManagedNotificationAccountContactCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DisassociateManagedNotificationAccountContactCommandInput - {@link DisassociateManagedNotificationAccountContactCommandInput}
 * @returns {@link DisassociateManagedNotificationAccountContactCommandOutput}
 * @see {@link DisassociateManagedNotificationAccountContactCommandInput} for command's `input` shape.
 * @see {@link DisassociateManagedNotificationAccountContactCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class DisassociateManagedNotificationAccountContactCommand extends DisassociateManagedNotificationAccountContactCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DisassociateManagedNotificationAccountContactRequest;
            output: {};
        };
        sdk: {
            input: DisassociateManagedNotificationAccountContactCommandInput;
            output: DisassociateManagedNotificationAccountContactCommandOutput;
        };
    };
}
