import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { GetEventRuleRequest, GetEventRuleResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetEventRuleCommand}.
 */
export interface GetEventRuleCommandInput extends GetEventRuleRequest {
}
/**
 * @public
 *
 * The output of {@link GetEventRuleCommand}.
 */
export interface GetEventRuleCommandOutput extends GetEventRuleResponse, __MetadataBearer {
}
declare const GetEventRuleCommand_base: {
    new (input: GetEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<GetEventRuleCommandInput, GetEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: GetEventRuleCommandInput): import("@smithy/smithy-client").CommandImpl<GetEventRuleCommandInput, GetEventRuleCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a specified <code>EventRule</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, GetEventRuleCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, GetEventRuleCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // GetEventRuleRequest
 *   arn: "STRING_VALUE", // required
 * };
 * const command = new GetEventRuleCommand(input);
 * const response = await client.send(command);
 * // { // GetEventRuleResponse
 * //   arn: "STRING_VALUE", // required
 * //   notificationConfigurationArn: "STRING_VALUE", // required
 * //   creationTime: new Date("TIMESTAMP"), // required
 * //   source: "STRING_VALUE", // required
 * //   eventType: "STRING_VALUE", // required
 * //   eventPattern: "STRING_VALUE", // required
 * //   regions: [ // Regions // required
 * //     "STRING_VALUE",
 * //   ],
 * //   managedRules: [ // ManagedRuleArns // required
 * //     "STRING_VALUE",
 * //   ],
 * //   statusSummaryByRegion: { // StatusSummaryByRegion // required
 * //     "<keys>": { // EventRuleStatusSummary
 * //       status: "STRING_VALUE", // required
 * //       reason: "STRING_VALUE", // required
 * //     },
 * //   },
 * // };
 *
 * ```
 *
 * @param GetEventRuleCommandInput - {@link GetEventRuleCommandInput}
 * @returns {@link GetEventRuleCommandOutput}
 * @see {@link GetEventRuleCommandInput} for command's `input` shape.
 * @see {@link GetEventRuleCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Request references a resource which does not exist. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class GetEventRuleCommand extends GetEventRuleCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: GetEventRuleRequest;
            output: GetEventRuleResponse;
        };
        sdk: {
            input: GetEventRuleCommandInput;
            output: GetEventRuleCommandOutput;
        };
    };
}
