import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListNotificationConfigurationsRequest, ListNotificationConfigurationsResponse } from "../models/models_0";
import { NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../NotificationsClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListNotificationConfigurationsCommand}.
 */
export interface ListNotificationConfigurationsCommandInput extends ListNotificationConfigurationsRequest {
}
/**
 * @public
 *
 * The output of {@link ListNotificationConfigurationsCommand}.
 */
export interface ListNotificationConfigurationsCommandOutput extends ListNotificationConfigurationsResponse, __MetadataBearer {
}
declare const ListNotificationConfigurationsCommand_base: {
    new (input: ListNotificationConfigurationsCommandInput): import("@smithy/smithy-client").CommandImpl<ListNotificationConfigurationsCommandInput, ListNotificationConfigurationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListNotificationConfigurationsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListNotificationConfigurationsCommandInput, ListNotificationConfigurationsCommandOutput, NotificationsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of abbreviated <code>NotificationConfigurations</code> according to
 *          specified filters, in reverse chronological order (newest first).</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { NotificationsClient, ListNotificationConfigurationsCommand } from "@aws-sdk/client-notifications"; // ES Modules import
 * // const { NotificationsClient, ListNotificationConfigurationsCommand } = require("@aws-sdk/client-notifications"); // CommonJS import
 * const client = new NotificationsClient(config);
 * const input = { // ListNotificationConfigurationsRequest
 *   eventRuleSource: "STRING_VALUE",
 *   channelArn: "STRING_VALUE",
 *   status: "STRING_VALUE",
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListNotificationConfigurationsCommand(input);
 * const response = await client.send(command);
 * // { // ListNotificationConfigurationsResponse
 * //   nextToken: "STRING_VALUE",
 * //   notificationConfigurations: [ // NotificationConfigurations // required
 * //     { // NotificationConfigurationStructure
 * //       arn: "STRING_VALUE", // required
 * //       name: "STRING_VALUE", // required
 * //       description: "STRING_VALUE", // required
 * //       status: "STRING_VALUE", // required
 * //       creationTime: new Date("TIMESTAMP"), // required
 * //       aggregationDuration: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListNotificationConfigurationsCommandInput - {@link ListNotificationConfigurationsCommandInput}
 * @returns {@link ListNotificationConfigurationsCommandOutput}
 * @see {@link ListNotificationConfigurationsCommandInput} for command's `input` shape.
 * @see {@link ListNotificationConfigurationsCommandOutput} for command's `response` shape.
 * @see {@link NotificationsClientResolvedConfig | config} for NotificationsClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>User does not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Unexpected error during processing of request.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Request was denied due to request throttling. </p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>This exception is thrown when the notification event fails validation.</p>
 *
 * @throws {@link NotificationsServiceException}
 * <p>Base exception class for all service exceptions from Notifications service.</p>
 *
 * @public
 */
export declare class ListNotificationConfigurationsCommand extends ListNotificationConfigurationsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListNotificationConfigurationsRequest;
            output: ListNotificationConfigurationsResponse;
        };
        sdk: {
            input: ListNotificationConfigurationsCommandInput;
            output: ListNotificationConfigurationsCommandOutput;
        };
    };
}
