import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { NotificationsServiceException as __BaseException } from "./NotificationsServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare const AccessStatus: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
  readonly PENDING: "PENDING";
};
export type AccessStatus = (typeof AccessStatus)[keyof typeof AccessStatus];
export declare const AccountContactType: {
  readonly ACCOUNT_ALTERNATE_BILLING: "ACCOUNT_ALTERNATE_BILLING";
  readonly ACCOUNT_ALTERNATE_OPERATIONS: "ACCOUNT_ALTERNATE_OPERATIONS";
  readonly ACCOUNT_ALTERNATE_SECURITY: "ACCOUNT_ALTERNATE_SECURITY";
  readonly ACCOUNT_PRIMARY: "ACCOUNT_PRIMARY";
};
export type AccountContactType =
  (typeof AccountContactType)[keyof typeof AccountContactType];
export interface SummarizationDimensionDetail {
  name: string | undefined;
  value: string | undefined;
}
export interface AggregationDetail {
  summarizationDimensions?: SummarizationDimensionDetail[] | undefined;
}
export declare const AggregationDuration: {
  readonly LONG: "LONG";
  readonly NONE: "NONE";
  readonly SHORT: "SHORT";
};
export type AggregationDuration =
  (typeof AggregationDuration)[keyof typeof AggregationDuration];
export declare const AggregationEventType: {
  readonly AGGREGATE: "AGGREGATE";
  readonly CHILD: "CHILD";
  readonly NONE: "NONE";
};
export type AggregationEventType =
  (typeof AggregationEventType)[keyof typeof AggregationEventType];
export interface AggregationKey {
  name: string | undefined;
  value: string | undefined;
}
export interface SummarizationDimensionOverview {
  name: string | undefined;
  count: number | undefined;
  sampleValues?: string[] | undefined;
}
export interface AggregationSummary {
  eventCount: number | undefined;
  aggregatedBy: AggregationKey[] | undefined;
  aggregatedAccounts: SummarizationDimensionOverview | undefined;
  aggregatedRegions: SummarizationDimensionOverview | undefined;
  aggregatedOrganizationalUnits?: SummarizationDimensionOverview | undefined;
  additionalSummarizationDimensions?:
    | SummarizationDimensionOverview[]
    | undefined;
}
export interface AssociateChannelRequest {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
}
export interface AssociateChannelResponse {}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  resourceId: string | undefined;
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare class InternalServerException extends __BaseException {
  readonly name: "InternalServerException";
  readonly $fault: "server";
  $retryable: {};
  constructor(
    opts: __ExceptionOptionType<InternalServerException, __BaseException>
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  resourceId: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  resourceType: string | undefined;
  resourceId?: string | undefined;
  serviceCode?: string | undefined;
  quotaCode?: string | undefined;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export declare class ThrottlingException extends __BaseException {
  readonly name: "ThrottlingException";
  readonly $fault: "client";
  $retryable: {
    throttling: boolean;
  };
  serviceCode?: string | undefined;
  quotaCode?: string | undefined;
  retryAfterSeconds?: number | undefined;
  constructor(
    opts: __ExceptionOptionType<ThrottlingException, __BaseException>
  );
}
export interface ValidationExceptionField {
  name: string | undefined;
  message: string | undefined;
}
export declare const ValidationExceptionReason: {
  readonly FIELD_VALIDATION_FAILED: "fieldValidationFailed";
  readonly OTHER: "other";
};
export type ValidationExceptionReason =
  (typeof ValidationExceptionReason)[keyof typeof ValidationExceptionReason];
export declare class ValidationException extends __BaseException {
  readonly name: "ValidationException";
  readonly $fault: "client";
  reason?: ValidationExceptionReason | undefined;
  fieldList?: ValidationExceptionField[] | undefined;
  constructor(
    opts: __ExceptionOptionType<ValidationException, __BaseException>
  );
}
export interface AssociateManagedNotificationAccountContactRequest {
  contactIdentifier: AccountContactType | undefined;
  managedNotificationConfigurationArn: string | undefined;
}
export interface AssociateManagedNotificationAccountContactResponse {}
export interface AssociateManagedNotificationAdditionalChannelRequest {
  channelArn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
}
export interface AssociateManagedNotificationAdditionalChannelResponse {}
export interface DisassociateChannelRequest {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
}
export interface DisassociateChannelResponse {}
export interface ListChannelsRequest {
  notificationConfigurationArn: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface ListChannelsResponse {
  nextToken?: string | undefined;
  channels: string[] | undefined;
}
export declare const ChannelAssociationOverrideOption: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type ChannelAssociationOverrideOption =
  (typeof ChannelAssociationOverrideOption)[keyof typeof ChannelAssociationOverrideOption];
export declare const ChannelType: {
  readonly ACCOUNT_CONTACT: "ACCOUNT_CONTACT";
  readonly CHATBOT: "CHATBOT";
  readonly EMAIL: "EMAIL";
  readonly MOBILE: "MOBILE";
};
export type ChannelType = (typeof ChannelType)[keyof typeof ChannelType];
export interface CreateEventRuleRequest {
  notificationConfigurationArn: string | undefined;
  source: string | undefined;
  eventType: string | undefined;
  eventPattern?: string | undefined;
  regions: string[] | undefined;
}
export declare const EventRuleStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly CREATING: "CREATING";
  readonly DELETING: "DELETING";
  readonly INACTIVE: "INACTIVE";
  readonly UPDATING: "UPDATING";
};
export type EventRuleStatus =
  (typeof EventRuleStatus)[keyof typeof EventRuleStatus];
export interface EventRuleStatusSummary {
  status: EventRuleStatus | undefined;
  reason: string | undefined;
}
export interface CreateEventRuleResponse {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  statusSummaryByRegion: Record<string, EventRuleStatusSummary> | undefined;
}
export interface CreateNotificationConfigurationRequest {
  name: string | undefined;
  description: string | undefined;
  aggregationDuration?: AggregationDuration | undefined;
  tags?: Record<string, string> | undefined;
}
export declare const NotificationConfigurationStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly DELETING: "DELETING";
  readonly INACTIVE: "INACTIVE";
  readonly PARTIALLY_ACTIVE: "PARTIALLY_ACTIVE";
};
export type NotificationConfigurationStatus =
  (typeof NotificationConfigurationStatus)[keyof typeof NotificationConfigurationStatus];
export interface CreateNotificationConfigurationResponse {
  arn: string | undefined;
  status: NotificationConfigurationStatus | undefined;
}
export interface DeleteEventRuleRequest {
  arn: string | undefined;
}
export interface DeleteEventRuleResponse {}
export interface DeleteNotificationConfigurationRequest {
  arn: string | undefined;
}
export interface DeleteNotificationConfigurationResponse {}
export interface DeregisterNotificationHubRequest {
  notificationHubRegion: string | undefined;
}
export declare const NotificationHubStatus: {
  readonly ACTIVE: "ACTIVE";
  readonly DEREGISTERING: "DEREGISTERING";
  readonly INACTIVE: "INACTIVE";
  readonly REGISTERING: "REGISTERING";
};
export type NotificationHubStatus =
  (typeof NotificationHubStatus)[keyof typeof NotificationHubStatus];
export interface NotificationHubStatusSummary {
  status: NotificationHubStatus | undefined;
  reason: string | undefined;
}
export interface DeregisterNotificationHubResponse {
  notificationHubRegion: string | undefined;
  statusSummary: NotificationHubStatusSummary | undefined;
}
export interface Dimension {
  name: string | undefined;
  value: string | undefined;
}
export interface DisableNotificationsAccessForOrganizationRequest {}
export interface DisableNotificationsAccessForOrganizationResponse {}
export interface DisassociateManagedNotificationAccountContactRequest {
  contactIdentifier: AccountContactType | undefined;
  managedNotificationConfigurationArn: string | undefined;
}
export interface DisassociateManagedNotificationAccountContactResponse {}
export interface DisassociateManagedNotificationAdditionalChannelRequest {
  channelArn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
}
export interface DisassociateManagedNotificationAdditionalChannelResponse {}
export interface EnableNotificationsAccessForOrganizationRequest {}
export interface EnableNotificationsAccessForOrganizationResponse {}
export interface GetEventRuleRequest {
  arn: string | undefined;
}
export interface GetEventRuleResponse {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  creationTime: Date | undefined;
  source: string | undefined;
  eventType: string | undefined;
  eventPattern: string | undefined;
  regions: string[] | undefined;
  managedRules: string[] | undefined;
  statusSummaryByRegion: Record<string, EventRuleStatusSummary> | undefined;
}
export interface ListEventRulesRequest {
  notificationConfigurationArn: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface EventRuleStructure {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  creationTime: Date | undefined;
  source: string | undefined;
  eventType: string | undefined;
  eventPattern: string | undefined;
  regions: string[] | undefined;
  managedRules: string[] | undefined;
  statusSummaryByRegion: Record<string, EventRuleStatusSummary> | undefined;
}
export interface ListEventRulesResponse {
  nextToken?: string | undefined;
  eventRules: EventRuleStructure[] | undefined;
}
export interface UpdateEventRuleRequest {
  arn: string | undefined;
  eventPattern?: string | undefined;
  regions?: string[] | undefined;
}
export interface UpdateEventRuleResponse {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  statusSummaryByRegion: Record<string, EventRuleStatusSummary> | undefined;
}
export declare const EventStatus: {
  readonly HEALTHY: "HEALTHY";
  readonly UNHEALTHY: "UNHEALTHY";
};
export type EventStatus = (typeof EventStatus)[keyof typeof EventStatus];
export declare const LocaleCode: {
  readonly de_DE: "de_DE";
  readonly en_CA: "en_CA";
  readonly en_UK: "en_UK";
  readonly en_US: "en_US";
  readonly es_ES: "es_ES";
  readonly fr_CA: "fr_CA";
  readonly fr_FR: "fr_FR";
  readonly id_ID: "id_ID";
  readonly it_IT: "it_IT";
  readonly ja_JP: "ja_JP";
  readonly ko_KR: "ko_KR";
  readonly pt_BR: "pt_BR";
  readonly tr_TR: "tr_TR";
  readonly zh_CN: "zh_CN";
  readonly zh_TW: "zh_TW";
};
export type LocaleCode = (typeof LocaleCode)[keyof typeof LocaleCode];
export interface GetManagedNotificationChildEventRequest {
  arn: string | undefined;
  locale?: LocaleCode | undefined;
}
export interface MessageComponents {
  headline?: string | undefined;
  paragraphSummary?: string | undefined;
  completeDescription?: string | undefined;
  dimensions?: Dimension[] | undefined;
}
export declare const NotificationType: {
  readonly ALERT: "ALERT";
  readonly ANNOUNCEMENT: "ANNOUNCEMENT";
  readonly INFORMATIONAL: "INFORMATIONAL";
  readonly WARNING: "WARNING";
};
export type NotificationType =
  (typeof NotificationType)[keyof typeof NotificationType];
export declare const SchemaVersion: {
  readonly SCHEMA_VERSION_1_0: "v1.0";
};
export type SchemaVersion = (typeof SchemaVersion)[keyof typeof SchemaVersion];
export declare const TextPartType: {
  readonly LOCALIZED_TEXT: "LOCALIZED_TEXT";
  readonly PLAIN_TEXT: "PLAIN_TEXT";
  readonly URL: "URL";
};
export type TextPartType = (typeof TextPartType)[keyof typeof TextPartType];
export interface TextPartValue {
  type: TextPartType | undefined;
  displayText?: string | undefined;
  textByLocale?: Partial<Record<LocaleCode, string>> | undefined;
  url?: string | undefined;
}
export interface ManagedNotificationChildEvent {
  schemaVersion: SchemaVersion | undefined;
  id: string | undefined;
  messageComponents: MessageComponents | undefined;
  sourceEventDetailUrl?: string | undefined;
  sourceEventDetailUrlDisplayText?: string | undefined;
  notificationType: NotificationType | undefined;
  eventStatus?: EventStatus | undefined;
  aggregateManagedNotificationEventArn: string | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  textParts: Record<string, TextPartValue> | undefined;
  organizationalUnitId?: string | undefined;
  aggregationDetail?: AggregationDetail | undefined;
}
export interface GetManagedNotificationChildEventResponse {
  arn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
  creationTime: Date | undefined;
  content: ManagedNotificationChildEvent | undefined;
}
export interface GetManagedNotificationConfigurationRequest {
  arn: string | undefined;
}
export interface GetManagedNotificationConfigurationResponse {
  arn: string | undefined;
  name: string | undefined;
  description: string | undefined;
  category: string | undefined;
  subCategory: string | undefined;
}
export interface GetManagedNotificationEventRequest {
  arn: string | undefined;
  locale?: LocaleCode | undefined;
}
export interface ManagedNotificationEvent {
  schemaVersion: SchemaVersion | undefined;
  id: string | undefined;
  messageComponents: MessageComponents | undefined;
  sourceEventDetailUrl?: string | undefined;
  sourceEventDetailUrlDisplayText?: string | undefined;
  notificationType: NotificationType | undefined;
  eventStatus?: EventStatus | undefined;
  aggregationEventType?: AggregationEventType | undefined;
  aggregationSummary?: AggregationSummary | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  textParts: Record<string, TextPartValue> | undefined;
  organizationalUnitId?: string | undefined;
}
export interface GetManagedNotificationEventResponse {
  arn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
  creationTime: Date | undefined;
  content: ManagedNotificationEvent | undefined;
}
export interface GetNotificationConfigurationRequest {
  arn: string | undefined;
}
export interface GetNotificationConfigurationResponse {
  arn: string | undefined;
  name: string | undefined;
  description: string | undefined;
  status: NotificationConfigurationStatus | undefined;
  creationTime: Date | undefined;
  aggregationDuration?: AggregationDuration | undefined;
}
export interface GetNotificationEventRequest {
  arn: string | undefined;
  locale?: LocaleCode | undefined;
}
export declare const MediaElementType: {
  readonly IMAGE: "IMAGE";
};
export type MediaElementType =
  (typeof MediaElementType)[keyof typeof MediaElementType];
export interface MediaElement {
  mediaId: string | undefined;
  type: MediaElementType | undefined;
  url: string | undefined;
  caption: string | undefined;
}
export interface Resource {
  id?: string | undefined;
  arn?: string | undefined;
  detailUrl?: string | undefined;
  tags?: string[] | undefined;
}
export interface SourceEventMetadata {
  eventTypeVersion: string | undefined;
  sourceEventId: string | undefined;
  eventOriginRegion?: string | undefined;
  relatedAccount: string | undefined;
  source: string | undefined;
  eventOccurrenceTime: Date | undefined;
  eventType: string | undefined;
  relatedResources: Resource[] | undefined;
}
export interface NotificationEventSchema {
  schemaVersion: SchemaVersion | undefined;
  id: string | undefined;
  sourceEventMetadata: SourceEventMetadata | undefined;
  messageComponents: MessageComponents | undefined;
  sourceEventDetailUrl?: string | undefined;
  sourceEventDetailUrlDisplayText?: string | undefined;
  notificationType: NotificationType | undefined;
  eventStatus?: EventStatus | undefined;
  aggregationEventType?: AggregationEventType | undefined;
  aggregateNotificationEventArn?: string | undefined;
  aggregationSummary?: AggregationSummary | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  textParts: Record<string, TextPartValue> | undefined;
  media: MediaElement[] | undefined;
}
export interface GetNotificationEventResponse {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  creationTime: Date | undefined;
  content: NotificationEventSchema | undefined;
}
export interface GetNotificationsAccessForOrganizationRequest {}
export interface NotificationsAccessForOrganization {
  accessStatus: AccessStatus | undefined;
}
export interface GetNotificationsAccessForOrganizationResponse {
  notificationsAccessForOrganization:
    | NotificationsAccessForOrganization
    | undefined;
}
export interface ListManagedNotificationChannelAssociationsRequest {
  managedNotificationConfigurationArn: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface ManagedNotificationChannelAssociationSummary {
  channelIdentifier: string | undefined;
  channelType: ChannelType | undefined;
  overrideOption?: ChannelAssociationOverrideOption | undefined;
}
export interface ListManagedNotificationChannelAssociationsResponse {
  nextToken?: string | undefined;
  channelAssociations:
    | ManagedNotificationChannelAssociationSummary[]
    | undefined;
}
export interface ListManagedNotificationChildEventsRequest {
  aggregateManagedNotificationEventArn: string | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  locale?: LocaleCode | undefined;
  maxResults?: number | undefined;
  relatedAccount?: string | undefined;
  organizationalUnitId?: string | undefined;
  nextToken?: string | undefined;
}
export interface MessageComponentsSummary {
  headline: string | undefined;
}
export interface ManagedSourceEventMetadataSummary {
  eventOriginRegion?: string | undefined;
  source: string | undefined;
  eventType: string | undefined;
}
export interface ManagedNotificationChildEventSummary {
  schemaVersion: SchemaVersion | undefined;
  sourceEventMetadata: ManagedSourceEventMetadataSummary | undefined;
  messageComponents: MessageComponentsSummary | undefined;
  aggregationDetail: AggregationDetail | undefined;
  eventStatus: EventStatus | undefined;
  notificationType: NotificationType | undefined;
}
export interface ManagedNotificationChildEventOverview {
  arn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
  relatedAccount: string | undefined;
  creationTime: Date | undefined;
  childEvent: ManagedNotificationChildEventSummary | undefined;
  aggregateManagedNotificationEventArn: string | undefined;
  organizationalUnitId?: string | undefined;
}
export interface ListManagedNotificationChildEventsResponse {
  nextToken?: string | undefined;
  managedNotificationChildEvents:
    | ManagedNotificationChildEventOverview[]
    | undefined;
}
export interface ListManagedNotificationConfigurationsRequest {
  channelIdentifier?: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface ManagedNotificationConfigurationStructure {
  arn: string | undefined;
  name: string | undefined;
  description: string | undefined;
}
export interface ListManagedNotificationConfigurationsResponse {
  nextToken?: string | undefined;
  managedNotificationConfigurations:
    | ManagedNotificationConfigurationStructure[]
    | undefined;
}
export interface ListManagedNotificationEventsRequest {
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  locale?: LocaleCode | undefined;
  source?: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
  organizationalUnitId?: string | undefined;
  relatedAccount?: string | undefined;
}
export interface ManagedNotificationEventSummary {
  schemaVersion: SchemaVersion | undefined;
  sourceEventMetadata: ManagedSourceEventMetadataSummary | undefined;
  messageComponents: MessageComponentsSummary | undefined;
  eventStatus: EventStatus | undefined;
  notificationType: NotificationType | undefined;
}
export interface ManagedNotificationEventOverview {
  arn: string | undefined;
  managedNotificationConfigurationArn: string | undefined;
  relatedAccount: string | undefined;
  creationTime: Date | undefined;
  notificationEvent: ManagedNotificationEventSummary | undefined;
  aggregationEventType?: AggregationEventType | undefined;
  organizationalUnitId?: string | undefined;
  aggregationSummary?: AggregationSummary | undefined;
  aggregatedNotificationRegions?: string[] | undefined;
}
export interface ListManagedNotificationEventsResponse {
  nextToken?: string | undefined;
  managedNotificationEvents: ManagedNotificationEventOverview[] | undefined;
}
export interface ListNotificationConfigurationsRequest {
  eventRuleSource?: string | undefined;
  channelArn?: string | undefined;
  status?: NotificationConfigurationStatus | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface NotificationConfigurationStructure {
  arn: string | undefined;
  name: string | undefined;
  description: string | undefined;
  status: NotificationConfigurationStatus | undefined;
  creationTime: Date | undefined;
  aggregationDuration?: AggregationDuration | undefined;
}
export interface ListNotificationConfigurationsResponse {
  nextToken?: string | undefined;
  notificationConfigurations: NotificationConfigurationStructure[] | undefined;
}
export interface ListNotificationEventsRequest {
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  locale?: LocaleCode | undefined;
  source?: string | undefined;
  includeChildEvents?: boolean | undefined;
  aggregateNotificationEventArn?: string | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface SourceEventMetadataSummary {
  eventOriginRegion?: string | undefined;
  source: string | undefined;
  eventType: string | undefined;
}
export interface NotificationEventSummary {
  schemaVersion: SchemaVersion | undefined;
  sourceEventMetadata: SourceEventMetadataSummary | undefined;
  messageComponents: MessageComponentsSummary | undefined;
  eventStatus: EventStatus | undefined;
  notificationType: NotificationType | undefined;
}
export interface NotificationEventOverview {
  arn: string | undefined;
  notificationConfigurationArn: string | undefined;
  relatedAccount: string | undefined;
  creationTime: Date | undefined;
  notificationEvent: NotificationEventSummary | undefined;
  aggregationEventType?: AggregationEventType | undefined;
  aggregateNotificationEventArn?: string | undefined;
  aggregationSummary?: AggregationSummary | undefined;
}
export interface ListNotificationEventsResponse {
  nextToken?: string | undefined;
  notificationEvents: NotificationEventOverview[] | undefined;
}
export interface ListNotificationHubsRequest {
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface NotificationHubOverview {
  notificationHubRegion: string | undefined;
  statusSummary: NotificationHubStatusSummary | undefined;
  creationTime: Date | undefined;
  lastActivationTime?: Date | undefined;
}
export interface ListNotificationHubsResponse {
  notificationHubs: NotificationHubOverview[] | undefined;
  nextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  arn: string | undefined;
}
export interface ListTagsForResourceResponse {
  tags?: Record<string, string> | undefined;
}
export interface UpdateNotificationConfigurationRequest {
  arn: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  aggregationDuration?: AggregationDuration | undefined;
}
export interface UpdateNotificationConfigurationResponse {
  arn: string | undefined;
}
export interface RegisterNotificationHubRequest {
  notificationHubRegion: string | undefined;
}
export interface RegisterNotificationHubResponse {
  notificationHubRegion: string | undefined;
  statusSummary: NotificationHubStatusSummary | undefined;
  creationTime: Date | undefined;
  lastActivationTime?: Date | undefined;
}
export interface TagResourceRequest {
  arn: string | undefined;
  tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  arn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
